durationtools.duration_token_to_assignable_duration_pairs
=========================================================

.. autofunction:: abjad.tools.durationtools.duration_token_to_assignable_duration_pairs.duration_token_to_assignable_duration_pairs
